componenttools.all_are_components_in_same_thread
================================================

.. autofunction:: abjad.tools.componenttools.all_are_components_in_same_thread.all_are_components_in_same_thread
